// File    : TVEDIT.H
// Author  : Eric Woodruff,  CIS ID: 72134,1150
// Updated : Thu 02/17/94 19:51:25
// Note    : Copyright 1994, Eric Woodruff, All rights reserved
// Compiler: Borland C++ 3.1/4.0
//
// Header file for the Virtual Memory Text Editor demo.
//

const
    cmAbout         = 100,          // Standard event values.
    cmRepaint       = 101,
    cmDOSshell      = 102,
    cmColors        = 103,
    cmChangePalettes = 104,
    cmLoadCfg       = 105,
    cmSaveCfg       = 106,
    cmCloseTileable = 107,
    cmScreenSize    = 108,
    cmUserScreen    = 109,

    cmOpen       = 110,             // Other command values.
    cmNew        = 111,
    cmChangeDrct = 112,
    cmShowClip   = 113,
    cmRecord     = 114,
    cmPlay       = 115,
    cmDefaultEditorOpt = 116,
    cmStartUpOpt = 117,

    cmMemoDemo   = 118,             // Demo stuff.
    cmKeyHelp    = 119,
    cmMsgViewer  = 120,
    cmReplaceKeyMaps = 121;

// Start up options structure
struct StartUp
{
    ushort EdOpts;
    short  bufSizeInK;
};

#define IndAtTop    0x01
#define SaveDeskTop 0x02

// Data structure for the demo.
struct DemoData
{
    ushort  Size1;            // The real size of this memo.
    char    ShortText[255];   // A short memo.

    ushort  Size2;            // The real size of this memo.
    char    LongText[1024];   // A long memo.
};

#if defined(Uses_TVMEditorApp)

#if !defined(__STDIO_H)
#include <stdio.h>        // Needed by FILE * for the macro file.
#endif

// Exit code values.
#define EXIT_NOERR      0
#define EXIT_RSCERR     1
#define EXIT_SYNTAX     2
#define EXIT_SWERR      3
#define EXIT_GENERR     4

class far TDeskTop;
class far TDialog;
class far TEvent;
class far TMenuBar;
class far TStatusLine;
class far TPalette;
class far TVMEditWindow;

#ifdef INCLUDE_HEAPVIEW
class far THeapView;
#endif

class TVMEditorApp : public TApplication
{
public:
    static FILE * near MacroFile;       // Macro file pointer.
    static ushort near MacroStatus;     // Macro play/record status.

    TVMEditorApp(void);
    static TMenuBar *initMenuBar(TRect r);
    static TStatusLine *initStatusLine(TRect r);
    static TDeskTop *initDeskTop(TRect r);

    virtual void initScreen();                  // Sets correct palette.
    virtual void idle(void);
    virtual void getEvent(TEvent &event);
    virtual void handleEvent(TEvent &event);
    virtual void outOfMemory(void);
    virtual TPalette& getPalette() const;

    void loadConfig(Boolean UseFileSetting);
    void saveConfig(void);
    void saveDeskTop(void);
    void restoreDeskTop(void);

private:
#ifdef INCLUDE_HEAPVIEW
    THeapView *heap;
#endif

    // State of CAPS and NumLock for the editors.
    // NOTE: This variable along with the overridden idle() function must
    // be present in the application class if the editor indicators are to
    // display the proper CAPS and NumLock settings at all times.
    uchar kbFlags;

    TVMEditWindow *openEditor(char *fileName, Boolean visible);

    void ReplaceKeyMaps(void);
    void MemoDemo(void);
    void DemoMsgViewer(void);
};

// A couple of useful functions.
ushort execDialog(TDialog *d, void *data);
Boolean isTileable(TView *p, void *);

// Other stuff.
extern TVMEditWindow *clipWindow;

class far TDialog;

ushort   doEditDialog(int dialog, ...);
ushort   doMemoEditDialog(int dialog, ...);

#endif
